<?php

namespace Drupal\elasticsearch_connector_suggester\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Event that is fired when the autocomplete name is requested.
 *
 * This event allows you to modify the autocomplete name before it is used.
 * This event is fired before elasticsearch query body changes the suggester.
 */
class FieldNameEvent extends Event {

  /**
   * The name.
   *
   * @var string
   */
  protected string $name;

  /**
   * The autocomplete name.
   *
   * @var string
   */
  protected string $autocompleteName;

  /**
   * The params.
   *
   * @var array
   */
  protected array $params;

  /**
   * Constructs a new RouteNameEvent.
   *
   * @param string $name
   *   The name.
   * @param string $autocomplete_name
   *   The autocomplete name.
   * @param array $params
   *   The params.
   */
  public function __construct(string $name, string $autocomplete_name, array $params) {
    $this->name = $name;
    $this->autocompleteName = $autocomplete_name;
    $this->params = $params;
  }

  /**
   * Gets the name.
   *
   * @return string
   *   The name.
   */
  public function getName(): string {
    return $this->name;
  }

  /**
   * Sets the name.
   *
   * @param string $name
   *   The name.
   */
  public function setName(string $name): void {
    $this->name = $name;
  }

  /**
   * Gets the autocomplete name.
   *
   * @return string
   *   The autocomplete name.
   */
  public function getAutocompleteName(): string {
    return $this->autocompleteName;
  }

  /**
   * Sets the autocomplete name.
   *
   * @param string $autocomplete_name
   *   The autocomplete name.
   */
  public function setAutocompleteNmae(string $autocomplete_name): void {
    $this->autocompleteName = $autocomplete_name;
  }

  /**
   * Get the params.
   *
   * @return array
   *   The params.
   */
  public function getParams(): array {
    return $this->params;
  }

}
