<?php

namespace Drupal\elasticsearch_connector_suggester\Event;

use Drupal\Component\EventDispatcher\Event;

/**
 * Event that is fired when the keys are requested.
 *
 * This event allows you to modify the search keys is used.
 * This event is fired before elasticsearch query body changes the suggester.
 */
class KeysEvent extends Event {

  /**
   * The keys.
   *
   * @var string
   */
  protected string $keys;

  /**
   * The params.
   *
   * @var array
   */
  protected array $params;

  /**
   * Constructs a new KeysEvent.
   *
   * @param string $keys
   *   The name.
   * @param array $params
   *   The params.
   */
  public function __construct(string $keys, array $params) {
    $this->keys = $keys;
    $this->params = $params;
  }

  /**
   * Gets the keys.
   *
   * @return string
   *   The name.
   */
  public function getKeys(): string {
    return $this->keys;
  }

  /**
   * Sets the keys.
   *
   * @param string $keys
   *   The name.
   */
  public function setKeys(string $keys): void {
    $this->keys = $keys;
  }

  /**
   * Gets the params.
   *
   * @return array
   *   The params.
   */
  public function getParams(): array {
    return $this->params;
  }

}
