<?php

namespace Drupal\elasticsearch_connector_suggester\EventSubscriber;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Config\ConfigEvents;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This is a subscriber for config save event.
 */
final class ConfigEventsSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a ConfigEventsSubscriber object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[ConfigEvents::SAVE] = [
      'onConfigSave',
    ];

    return $events;
  }

  /**
   * Called on config.save event.
   *
   * Update elasticsearch index mapping.
   *
   * @param \Drupal\Core\Config\ConfigCrudEvent $event
   *   The event.
   */
  public function onConfigSave(Event $event) {
    /** @var \Drupal\Core\Config\Config $config */
    $config = $event->getConfig();
    $name = $config->getName();
    if (!preg_match('/^search_api_autocomplete.search.*$/', $name)) {
      return;
    }
    // Save index to update mapping.
    if ($index = $this->entityTypeManager->getStorage('search_api_index')
      ->load($config->get('index_id'))) {
      $index->save();
    }
  }

}
