<?php

namespace Drupal\elasticsearch_connector_suggester\EventSubscriber;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\elasticsearch_connector\Event\FieldMappingEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This is a subscriber for the FieldMappingEvent event.
 */
final class FieldMappingEventSubscriber implements EventSubscriberInterface {

  use SubscriberTrait;

  /**
   * Constructs a FieldMappingEventSubscriber object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[FieldMappingEvent::class] = [
      'onFieldMapping',
    ];

    return $events;
  }

  /**
   * Called on elasticsearch FieldMappingEvent event.
   *
   * Change suggester field type to completion.
   *
   * @param \Drupal\elasticsearch_connector\Event\FieldMappingEvent $event
   *   The event.
   */
  public function onFieldMapping(Event $event) {
    $index = $event->getField()->getIndex();
    $param = $event->getParam();
    $fields = $this->getFields($index);
    if (empty($fields)) {
      return;
    }
    $field = array_shift($fields);
    $field_id = $event->getField()->getFieldIdentifier();
    if ($field_id != $field) {
      return;
    }

    // Get suggester analyzer.
    $analizer = 'keyword';
    // Load search for index.
    /** @var \Drupal\search_api_autocomplete\SearchInterface[] $searches */
    $searches = $this->entityTypeManager
      ->getStorage('search_api_autocomplete_search')
      ->loadByProperties([
        'index_id' => $index->id(),
      ]);
    /** @var \Drupal\search_api_autocomplete\SearchInterface $search */
    $search = array_shift($searches);
    if (is_a($search, 'Drupal\search_api_autocomplete\Entity\Search')) {
      // Get suggester for search.
      /** @var \Drupal\search_api_autocomplete\Suggester\SuggesterInterface $suggester */
      $suggester = $search->getSuggester('elastic_live_results');
      if (is_a($suggester, 'Drupal\search_api_autocomplete\Suggester\SuggesterInterface')) {
        // Get suggester analyzer.
        $analizer = $suggester->getConfiguration()['analyzer'] ?? 'keyword';
      }
    }

    // Set the field completion property.
    $param['fields']['completion'] = [
      'type' => 'completion',
      'analyzer' => $analizer,
      'max_input_length' => 1000,
    ];

    $event->setParam($param);
  }

}
