<?php

namespace Drupal\elasticsearch_connector_suggester\EventSubscriber;

use Drupal\Component\EventDispatcher\Event;
use Drupal\search_api\Event\SearchApiEvents;
use Drupal\search_api\Utility\FieldsHelperInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This is the SearchApiProcessingResultsSubscriber class.
 */
final class SearchApiProcessingResultsSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a SearchApiProcessingResultsSubscriber object.
   */
  public function __construct(
    private readonly FieldsHelperInterface $fieldsHelper,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[SearchApiEvents::PROCESSING_RESULTS] = [
      'onSearchApiProcessingResults',
    ];

    return $events;
  }

  /**
   * Called on search_api.processing_results event.
   *
   * Add suggester results.
   *
   * @param \Drupal\search_api\Event\ProcessingResultsEvent $event
   *   The event.
   */
  public function onSearchApiProcessingResults(Event $event) {
    /** @var \Drupal\search_api\Query\ResultSet $results */
    $results = $event->getResults();
    if (!empty($results->getResultItems())) {
      return;
    }
    $query = $results->getQuery();
    $index = $query->getIndex();
    $response = $results->getExtraData('elasticsearch_response');
    $suggestions = $response['suggest']['autocomplete'][0]['options'] ?? [];
    array_map(function ($item) use ($index, &$results) {
      $result_item = $this->fieldsHelper->createItem($index, $item['_id']);
      $result_item->setScore($item['_score']);
      $results->addResultItem($result_item);
    }, $suggestions);
  }

}
